@@ -1,7 +1,7 @@
 #!/bin/sh
 ## This is what a simple SSH tunnel might look like:
 USER=avenj
-ENDPOINT=your.remote.server
+ENDPOINT=eris
 LOCALPORT=5511
 REMOTEPORT=5511
 ssh -f ${USER}@${ENDPOINT} \
@@ -10,13 +10,12 @@ ssh -f ${USER}@${ENDPOINT} \
 ##
 :<<'CMTBLK'
 
-... then bind() tcp://127.0.0.1:REMOTEPORT on the remote side and connect()
-127.0.0.1:LOCALPORT on the side running the tunnel.
+... then bind tcp://127.0.0.1:REMOTEPORT and connect 127.0.0.1:LOCALPORT
+on the side running the tunnel. (You only want to do this if you control the
+systems involved, obviously.)
 
-SSH is a pretty convenient poor man's VPN, providing an encrypted
-channel to talk to a remote ZMQ socket that is only bound to localhost.
-ZeroMQ 4+ has built-in encryption support, but SSH will work for 3.x or mixed
-networks using insecure transports.
+SSH is a pretty convenient poor man's VPN, providing a secure
+way to talk to a remote ZMQ socket that is only bound to localhost.
 
 This is far more useful when combined with OpenSSH's certificate support
 -- see the 'CERTIFICATES' section of ssh-keygen(1):
