@@ -14,8 +14,6 @@ has targets => (
   default => sub { [] },
 );
 
-sub ZALIAS () { 'sub' }
-
 with 'POEx::ZMQ3::Role::Emitter';
 
 sub build_defined_states {
@@ -33,7 +31,8 @@ sub start {
   my ($self, @targets) = @_;
   push @{ $self->targets }, @targets;
   $self->zmq->start;
-  $self->zmq->create( ZALIAS, 'SUB' );
+
+  $self->zmq->create( $self->alias, 'SUB' );
 
   $self->_start_emitter;
 }
@@ -42,8 +41,8 @@ sub emitter_started {
   my ($kernel, $self) = @_[KERNEL, OBJECT];
 
   $kernel->call( $self->zmq => subscribe => 'all' );
-  $self->zmq->set_zmq_subscribe( ZALIAS );
-  $self->add_connect( ZALIAS, $_ ) for @{ $self->targets };
+  $self->zmq->set_zmq_subscribe( $self->alias );
+  $self->add_connect( $self->alias, $_ ) for @{ $self->targets };
   $self->targets([]);
 
   $self
@@ -69,7 +68,7 @@ sub zmqsock_recv {
 sub zmqsock_multipart_recv {
   my ($kernel, $self) = @_[KERNEL, OBJECT];
   my ($alias, $parts) = @_[ARG0, ARG1];
-  ## FIXME
+  $self->emit( 'received', @$parts )
 }
 
 1;
@@ -153,9 +152,18 @@ Emitted when we are initialized; $_[ARG0] is the target publisher's address.
 
 =head3 zeromq_received
 
-Emitted when we receive data from the publisher we are subscribed to; $_[ARG0]
-is the (raw) data received. (No special handling of multipart messages
-currently takes place.)
+Emitted when we receive data from the publisher we are subscribed to
+
+If this is a single-part message, $_[ARG0] is the (raw) data received. 
+
+If this is a multi-part message, slurp the argument array to receive all
+parts:
+
+  sub zeromq_received {
+    my @parts    = @_[ARG0 .. $#_];
+    my $envelope = shift @parts;
+    . . .
+  }
 
 =head1 SEE ALSO
 
